[Libreoffice-commits] core.git: ucb/source

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Tue Sep 1 20:03:52 UTC 2020


 ucb/source/ucp/ext/ucpext_content.cxx |   22 +++++++++++-----------
 1 file changed, 11 insertions(+), 11 deletions(-)

New commits:
commit cdf8e4f6496391b2b77741c7ffb8bba6f70a6557
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Mon Aug 31 16:07:04 2020 +0200
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Tue Sep 1 22:03:13 2020 +0200

    Fix typo in code
    
    It passed "make check" on linux
    
    Change-Id: I8322ecf2a4c960524fd45cd63fd991d9fa0a3590
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101796
    Tested-by: Jenkins
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/ucb/source/ucp/ext/ucpext_content.cxx b/ucb/source/ucp/ext/ucpext_content.cxx
index 58d0dcb31fad..86d265db5535 100644
--- a/ucb/source/ucp/ext/ucpext_content.cxx
+++ b/ucb/source/ucp/ext/ucpext_content.cxx
@@ -174,7 +174,7 @@ namespace ucb::ucp::ext
     }
 
 
-    Any SAL_CALL Content::execute( const Command& aCommand, sal_Int32 /* CommandId */, const Reference< XCommandEnvironment >& i_rEvironment )
+    Any SAL_CALL Content::execute( const Command& aCommand, sal_Int32 /* CommandId */, const Reference< XCommandEnvironment >& i_rEnvironment )
     {
         Any aRet;
 
@@ -185,11 +185,11 @@ namespace ucb::ucp::ext
             {
                 ::ucbhelper::cancelCommandExecution( makeAny( IllegalArgumentException(
                     OUString(), *this, -1 ) ),
-                    i_rEvironment );
+                    i_rEnvironment );
                 // unreachable
             }
 
-            aRet <<= getPropertyValues( Properties, i_rEvironment );
+            aRet <<= getPropertyValues( Properties, i_rEnvironment );
         }
         else if ( aCommand.Name == "setPropertyValues" )
         {
@@ -198,7 +198,7 @@ namespace ucb::ucp::ext
             {
                 ::ucbhelper::cancelCommandExecution( makeAny( IllegalArgumentException(
                     OUString(), *this, -1 ) ),
-                    i_rEvironment );
+                    i_rEnvironment );
                 // unreachable
             }
 
@@ -206,7 +206,7 @@ namespace ucb::ucp::ext
             {
                 ::ucbhelper::cancelCommandExecution( makeAny( IllegalArgumentException(
                     OUString(), *this, -1 ) ),
-                    i_rEvironment );
+                    i_rEnvironment );
                 // unreachable
             }
 
@@ -215,12 +215,12 @@ namespace ucb::ucp::ext
         else if ( aCommand.Name == "getPropertySetInfo" )
         {
             // implemented by base class.
-            aRet <<= getPropertySetInfo( i_rEvironment );
+            aRet <<= getPropertySetInfo( i_rEnvironment );
         }
         else if ( aCommand.Name == "getCommandInfo" )
         {
             // implemented by base class.
-            aRet <<= getCommandInfo( i_rEvironment );
+            aRet <<= getCommandInfo( i_rEnvironment );
         }
         else if ( aCommand.Name == "open" )
         {
@@ -229,7 +229,7 @@ namespace ucb::ucp::ext
             {
                 ::ucbhelper::cancelCommandExecution( makeAny( IllegalArgumentException(
                     OUString(), *this, -1 ) ),
-                    i_rEvironment );
+                    i_rEnvironment );
                 // unreachable
             }
 
@@ -241,14 +241,14 @@ namespace ucb::ucp::ext
 
             if ( bOpenFolder && impl_isFolder() )
             {
-                Reference< XDynamicResultSet > xSet = new ResultSet( m_xContext, this, aOpenCommand, i_rEvironment );
+                Reference< XDynamicResultSet > xSet = new ResultSet( m_xContext, this, aOpenCommand, i_rEnvironment );
                 aRet <<= xSet;
               }
 
             if ( aOpenCommand.Sink.is() )
             {
                 const OUString sPhysicalContentURL( getPhysicalURL() );
-                ::ucbhelper::Content aRequestedContent( sPhysicalContentURL, i_rEvironment, m_xContext );
+                ::ucbhelper::Content aRequestedContent( sPhysicalContentURL, i_rEnvironment, m_xContext );
                 aRet = aRequestedContent.executeCommand( "open", makeAny( aOpenCommand ) );
             }
         }
@@ -257,7 +257,7 @@ namespace ucb::ucp::ext
         {
             ::ucbhelper::cancelCommandExecution( makeAny( UnsupportedCommandException(
                 OUString(), *this ) ),
-                i_rEvironment );
+                i_rEnvironment );
             // unreachable
         }
 


More information about the Libreoffice-commits mailing list